@@ -5,7 +5,7 @@
 #
 # See the README for full license details.
 # 
-# $Id: webunittest.py,v 1.12 2004/01/21 22:41:46 richard Exp $
+# $Id: webunittest.py,v 1.13 2004/08/26 02:50:19 richard Exp $
 
 import os, base64, urllib, urlparse, unittest, cStringIO, time, re, sys
 import httplib
@@ -56,6 +56,7 @@ class WebFetcher:
         self.expect_content = None
         self.expect_cookies = None
         self.accept_cookies = 1
+        self.debug_headers = 0
         self.cookies = {}
 
     result_count = 0
@@ -362,6 +363,7 @@ class WebFetcher:
         else:
             raise ValueError, protocol
 
+        headers = []
         params = None
         if postdata:
             for field,value in postdata.items():
@@ -373,17 +375,17 @@ class WebFetcher:
             # Do a post with the data file
             params = mimeEncode(postdata)
             h.putrequest('POST', url)
-            h.putheader('Content-type', 'multipart/form-data; boundary=%s'%
-                boundary)
-            h.putheader('Content-length', str(len(params)))
+            headers.append(('Content-type',
+                'multipart/form-data; boundary=%s'%boundary))
+            headers.append(('Content-length', str(len(params))))
         else:
             # Normal GET
             h.putrequest('GET', url)
 
         # Other Full Request headers
         if self.authinfo:
-            h.putheader('Authorization', "Basic %s"%self.authinfo)
-        h.putheader('Host', host_header)
+            headers.append(('Authorization', "Basic %s"%self.authinfo))
+        headers.append(('Host', host_header))
 
         # Send cookies
         #  - check the domain, max-age (seconds), path and secure
@@ -410,7 +412,7 @@ class WebFetcher:
                     cookies_used.append(sendcookie.key)
 
         if cookie_list:
-            h.putheader('Cookie', ' '.join(cookie_list))
+            headers.append(('Cookie', ' '.join(cookie_list)))
 
         # check that we sent the cookies we expected to
         if self.expect_cookies is not None:
@@ -418,9 +420,14 @@ class WebFetcher:
                 "Didn't use all cookies (%s expected, %s used)"%(
                 self.expect_cookies, cookies_used)
 
-        # finish the headers
+        # write and finish the headers
+        for header in headers:
+            h.putheader(*header)
         h.endheaders()
 
+        if self.debug_headers:
+            import pprint;pprint.pprint(headers)
+
         if params is not None:
             h.send(params)
 
@@ -460,7 +467,8 @@ class WebFetcher:
             data = response.body
             for content in self.error_content:
                 if data.find(content) != -1:
-                    msg = "Matched error: %s"%content
+                    url = urlparse.urlunparse((protocol, server, url, '','',''))
+                    msg = "URL %r matched error: %s"%(url, content)
                     if hasattr(self, 'results') and self.results:
                         self.writeError(url, msg)
                     self.log('Matched error'+`(url, content)`, data)
@@ -673,6 +681,9 @@ class HTTPResponse(WebFetcher, unittest.TestCase):
 
 #
 # $Log: webunittest.py,v $
+# Revision 1.13  2004/08/26 02:50:19  richard
+# more info
+#
 # Revision 1.12  2004/01/21 22:41:46  richard
 # *** empty log message ***
 #
